summaryrefslogtreecommitdiffstats
path: root/kjsembed/tools/headers/qpen.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/tools/headers/qpen.h')
-rw-r--r--kjsembed/tools/headers/qpen.h54
1 files changed, 27 insertions, 27 deletions
diff --git a/kjsembed/tools/headers/qpen.h b/kjsembed/tools/headers/qpen.h
index 585e7af2..e1a5c582 100644
--- a/kjsembed/tools/headers/qpen.h
+++ b/kjsembed/tools/headers/qpen.h
@@ -1,7 +1,7 @@
/****************************************************************************
**
**
** Definition of TQPen class
**
** Created : 940112
**
@@ -11,7 +11,7 @@
**
** This file may be distributed under the terms of the Q Public License
** as defined by Trolltech AS of Norway and appearing in the file
-** LICENSE.QPL included in the packaging of this file.
+** LICENSE.TQPL included in the packaging of this file.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
@@ -27,7 +27,7 @@
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
** information about Qt Commercial License Agreements.
-** See http://www.trolltech.com/qpl/ for QPL licensing information.
+** See http://www.trolltech.com/qpl/ for TQPL licensing information.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
@@ -35,8 +35,8 @@
**
**********************************************************************/
-#ifndef QPEN_H
-#define QPEN_H
+#ifndef TQPEN_H
+#define TQPEN_H
#ifndef QT_H
#include "tqcolor.h"
@@ -44,56 +44,56 @@
#endif // QT_H
-class Q_EXPORT TQPen: public Qt
+class Q_EXPORT TTQPen: public Qt
{
public:
- TQPen();
- TQPen( PenStyle );
- TQPen( const TQColor &color, uint width=0, PenStyle style=SolidLine );
- TQPen( const TQColor &cl, uint w, PenStyle s, PenCapStyle c, PenJoinStyle j);
- TQPen( const TQPen & );
- ~TQPen();
- TQPen &operator=( const TQPen & );
+ TTQPen();
+ TTQPen( PenStyle );
+ TTQPen( const TTQColor &color, uint width=0, PenStyle style=SolidLine );
+ TTQPen( const TTQColor &cl, uint w, PenStyle s, PenCapStyle c, PenJoinStyle j);
+ TTQPen( const TTQPen & );
+ ~TTQPen();
+ TTQPen &operator=( const TTQPen & );
PenStyle style() const { return data->style; }
void setStyle( PenStyle );
uint width() const { return data->width; }
void setWidth( uint );
- const TQColor &color() const { return data->color; }
- void setColor( const TQColor & );
+ const TTQColor &color() const { return data->color; }
+ void setColor( const TTQColor & );
PenCapStyle capStyle() const;
void setCapStyle( PenCapStyle );
PenJoinStyle joinStyle() const;
void setJoinStyle( PenJoinStyle );
- bool operator==( const TQPen &p ) const;
- bool operator!=( const TQPen &p ) const
+ bool operator==( const TTQPen &p ) const;
+ bool operator!=( const TTQPen &p ) const
{ return !(operator==(p)); }
private:
- friend class TQPainter;
+ friend class TTQPainter;
#ifdef Q_WS_WIN
- friend class QFontEngineWin;
+ friend class TQFontEngineWin;
#endif
- QPen copy() const;
+ TQPen copy() const;
void detach();
- void init( const TQColor &, uint, uint );
- struct QPenData : public QShared { // pen data
+ void init( const TTQColor &, uint, uint );
+ struct TQPenData : public TQShared { // pen data
PenStyle style;
uint width;
- QColor color;
+ TQColor color;
Q_UINT16 linest;
} *data;
};
/*****************************************************************************
- TQPen stream functions
+ TTQPen stream functions
*****************************************************************************/
#ifndef QT_NO_DATASTREAM
-Q_EXPORT TQDataStream &operator<<( TQDataStream &, const TQPen & );
-Q_EXPORT TQDataStream &operator>>( TQDataStream &, TQPen & );
+Q_EXPORT TTQDataStream &operator<<( TTQDataStream &, const TTQPen & );
+Q_EXPORT TTQDataStream &operator>>( TTQDataStream &, TTQPen & );
#endif
-#endif // QPEN_H
+#endif // TQPEN_H
@@ -1,7 +1,7 @@
**
**
-** Definition of TQPen class
+** Definition of TTQPen class
**
** Created : 940112